This directory contains representations of schemas for a number of resources,
including but not limited to: 

- urn:ietf:params:scim:schemas:core:2.0:User
- urn:ietf:params:scim:schemas:core:2.0:Group
- urn:ietf:params:scim:schemas:extension:enterprise:2.0:User
- urn:ietf:params:scim:schemas:core:2.0:ServiceProviderConfig
- urn:ietf:params:scim:schemas:core:2.0:ResourceType
- urn:ietf:params:scim:schemas:core:2.0:Schema


Copied from: https://tools.ietf.org/html/rfc7643#section-8.7

